summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/test_shell.h
diff options
context:
space:
mode:
authordeanm@chromium.org <deanm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-04 16:54:01 +0000
committerdeanm@chromium.org <deanm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-04 16:54:01 +0000
commitbbe0af065171c8c3c226ab45087822d37218fb77 (patch)
tree7094fce066b9c4d1e6eb4822a06884dbb45be67d /webkit/tools/test_shell/test_shell.h
parentbe8c5ad496da6dabb5d3689b0613348fffbed4c9 (diff)
downloadchromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.zip
chromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.tar.gz
chromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.tar.bz2
Unify on "layout test mode" vs "interactive" and "non-interactive". We had a layout test mode flag in some places, and an interactive flag in others. It was especially confusing since interactive = !layout_test_mode.
This should make it much easier to grep for difference between layout test mode and normal "interactive" mode. Review URL: http://codereview.chromium.org/12940 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6357 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/tools/test_shell/test_shell.h')
-rw-r--r--webkit/tools/test_shell/test_shell.h21
1 files changed, 10 insertions, 11 deletions
diff --git a/webkit/tools/test_shell/test_shell.h b/webkit/tools/test_shell/test_shell.h
index 62ca208..95b0d47 100644
--- a/webkit/tools/test_shell/test_shell.h
+++ b/webkit/tools/test_shell/test_shell.h
@@ -76,10 +76,10 @@ public:
static void CleanupLogging();
// Initialization and clean up of a static member variable.
- static void InitializeTestShell(bool interactive);
+ static void InitializeTestShell(bool layout_test_mode);
static void ShutdownTestShell();
- static bool interactive() { return interactive_; }
+ static bool layout_test_mode() { return layout_test_mode_; }
// Called from the destructor to let each platform do any necessary
// cleanup.
@@ -100,8 +100,7 @@ public:
void Show(WebView* webview, WindowOpenDisposition disposition);
// We use this to avoid relying on Windows focus during non-interactive
// mode.
void SetFocus(WebWidgetHost* host, bool enable);
LayoutTestController* layout_test_controller() {
@@ -125,19 +124,19 @@ public:
// Passes options from LayoutTestController through to the delegate (or
// any other caller).
bool ShouldDumpEditingCallbacks() {
- return !interactive_ &&
+ return layout_test_mode_ &&
layout_test_controller_->ShouldDumpEditingCallbacks();
}
bool ShouldDumpFrameLoadCallbacks() {
- return !interactive_ && (test_is_preparing_ || test_is_pending_) &&
+ return layout_test_mode_ && (test_is_preparing_ || test_is_pending_) &&
layout_test_controller_->ShouldDumpFrameLoadCallbacks();
}
bool ShouldDumpResourceLoadCallbacks() {
- return !interactive_ && (test_is_preparing_ || test_is_pending_) &&
+ return layout_test_mode_ && (test_is_preparing_ || test_is_pending_) &&
layout_test_controller_->ShouldDumpResourceLoadCallbacks();
}
bool ShouldDumpTitleChanges() {
- return !interactive_ &&
+ return layout_test_mode_ &&
layout_test_controller_->ShouldDumpTitleChanges();
}
bool AcceptsEditing() {
@@ -288,10 +287,10 @@ private:
static HINSTANCE instance_handle_;
#endif
- // False when the app is being run using the --layout-tests switch.
- static bool interactive_;
+ // True when the app is being run using the --layout-tests switch.
+ static bool layout_test_mode_;
- // Timeout for page load when running non-interactive file tests, in ms.
+ // Default timeout in ms for file page loads when in layout test mode.
static int file_test_timeout_ms_;
scoped_ptr<LayoutTestController> layout_test_controller_;
@@ -100,8 +100,7 @@ public:
void Show(WebView* webview, WindowOpenDisposition disposition);
- // We use this to avoid relying on Windows focus during non-interactive
- // mode.
+ // We use this to avoid relying on Windows focus during layout test mode.
void SetFocus(WebWidgetHost* host, bool enable);
LayoutTestController* layout_test_controller() {